@@ -4,7 +4,7 @@ from pathlib import Path as _Path
 
 from .bosl2_base import Bosl2Base as _Bosl2Base
 
-_extra_scad_include(f"{_Path(__file__).parent.parent / '../libs/BOSL2/structs.scad'}", use_not_include=False)
+_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/structs.scad'}", use_not_include=False)
 
 class struct_set(_Bosl2Base):
     def __init__(self, struct=None, key=None, value=None, grow=None, **kwargs):
